/* $Id: filesystem.h,v 1.2 2000/02/19 11:16:16 proff Exp $ */

#ifndef FILESYSTEM_H
#define FILESYSTEM_H

#include <sys/types.h>
#ifdef HAVE_SYS_PARAM_H
#  include <sys/param.h>
#endif
#ifdef HAVE_SYS_MOUNT_H
#  include <sys/mount.h>
#endif
#ifdef HAVE_SYS_VFS_H
#  include <sys/vfs.h>
#endif
#ifdef HAVE_SYS_STATVFS_H
#  include <sys/statvfs.h>
#endif
#ifdef HAVE_SYS_STATFS_H
#  include <sys/statfs.h>
#endif
#include <dirent.h>
#endif
